package com.yc.ship.module.otc.service.storescheduling;

import com.yc.ship.framework.common.pojo.PageResult;
import com.yc.ship.module.otc.controller.admin.storescheduling.vo.StoreSchedulingPageReqVO;
import com.yc.ship.module.otc.controller.admin.storescheduling.vo.StoreSchedulingSaveReqVO;
import com.yc.ship.module.otc.dal.dataobject.storescheduling.StoreSchedulingDO;

import javax.validation.Valid;
import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * 班次管理 Service 接口
 *
 * @author 管理员
 */
public interface StoreSchedulingService {

    /**
     * 创建班次管理
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createStoreScheduling(@Valid StoreSchedulingSaveReqVO createReqVO);

    /**
     * 更新班次管理
     *
     * @param updateReqVO 更新信息
     */
    void updateStoreScheduling(@Valid StoreSchedulingSaveReqVO updateReqVO);

    /**
     * 删除班次管理
     *
     * @param id 编号
     */
    void deleteStoreScheduling(Long id);

    /**
     * 获得班次管理
     *
     * @param id 编号
     * @return 班次管理
     */
    StoreSchedulingDO getStoreScheduling(Long id);

    /**
     * 获得班次管理分页
     *
     * @param pageReqVO 分页查询
     * @return 班次管理分页
     */
    PageResult<StoreSchedulingDO> getStoreSchedulingPage(StoreSchedulingPageReqVO pageReqVO);


    List<StoreSchedulingDO> getSchedulingListByStatus();

    /**
     * 获得站点列表
     *
     * @param ids 站点编号数组
     * @return 站点列表
     */
    List<StoreSchedulingDO> getSchedulingList(Collection<Long> ids);

    Map<Long, StoreSchedulingDO> getSchedulingMap(Collection<Long> ids);

}
