package com.yc.ship.module.resource.controller.admin.supplier.vo;

import com.yc.ship.framework.common.pojo.PageParam;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.ToString;
import org.springframework.format.annotation.DateTimeFormat;

import java.time.LocalDate;
import java.time.LocalDateTime;

import static com.yc.ship.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY;
import static com.yc.ship.framework.common.util.date.DateUtils.FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND;


@Schema(description = "管理后台 - 资源供应商分页 Request VO")
@Data
@EqualsAndHashCode(callSuper = true)
@ToString(callSuper = true)
public class SupplierPageReqVO extends PageParam {

    @Schema(description = "供应商名称", example = "张三")
    private String name;

    @Schema(description = "简称", example = "张三")
    private String shortName;

    @Schema(description = "供应商类型（0：内部供应商，1：外部供应商）", example = "2")
    private Integer type;

    @Schema(description = "合作状态（0：合作中止，1：合作中）", example = "2")
    private Integer useStatus;

    @Schema(description = "合作开始时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY)
    private LocalDate cooperateStartTime;

    @Schema(description = "合作结束时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY)
    private LocalDate cooperateEndTime;

    @Schema(description = "联系人")
    private String contactMan;

    @Schema(description = "联系电话")
    private String contactPhone;

    @Schema(description = "联系地址")
    private String contactAddress;

    @Schema(description = "业务区域")
    private String businessArea;

    @Schema(description = "合同")
    private String contract;

    @Schema(description = "是否系统直连（0：否，1-是）")
    private Integer isSystemDirect;

    @Schema(description = "系统直连参数")
    private String directParam;

    @Schema(description = "系统直连账号", example = "4537")
    private String directAccount;

    @Schema(description = "系统直连下单地址", example = "https://www.iocoder.cn")
    private String directOrderUrl;

    @Schema(description = "系统直连核销地址", example = "https://www.iocoder.cn")
    private String directCheckUrl;

    @Schema(description = "系统直连退票地址", example = "https://www.iocoder.cn")
    private String directRefundUrl;

    @Schema(description = "直连供应商系统", example = "OtaService")
    private String directServer;

    @Schema(description = "提供资源类型", example = "2")
    private String resourceType;

    @Schema(description = "单位名称（同供应商名称）", example = "王五")
    private String unitName;

    @Schema(description = "单位地址")
    private String unitAddress;

    @Schema(description = "开户行", example = "赵六")
    private String bankName;

    @Schema(description = "银行账户", example = "14227")
    private String bankAccount;

    @Schema(description = "税号", example = "6791")
    private String taxId;

    @Schema(description = "电话")
    private String telephone;

    @Schema(description = "联行号")
    private String interbankNumber;

    @Schema(description = "创建时间")
    @DateTimeFormat(pattern = FORMAT_YEAR_MONTH_DAY_HOUR_MINUTE_SECOND)
    private LocalDateTime[] createTime;

}