package com.yc.ship.module.resource.controller.admin.supplier.vo;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;
import com.yc.ship.framework.excel.core.annotations.DictFormat;
import com.yc.ship.framework.excel.core.convert.DictConvert;
import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import java.time.LocalDateTime;
import java.util.List;

@Schema(description = "管理后台 - 资源供应商 Response VO")
@Data
@ExcelIgnoreUnannotated
public class SupplierRespVO {

    @Schema(description = "主键", requiredMode = Schema.RequiredMode.REQUIRED, example = "10823")
    private Long id;

    @Schema(description = "供应商名称", example = "张三")
    @ExcelProperty("供应商名称")
    private String name;

    @Schema(description = "简称", example = "张三")
    @ExcelProperty("简称")
    private String shortName;

    @Schema(description = "供应商类型（0：内部供应商，1：外部供应商）", example = "2")
    @ExcelProperty(value = "供应商类型", converter = DictConvert.class)
    @DictFormat("supplier_type")
    private Integer type;

    @Schema(description = "合作状态（0：合作中止，1：合作中）", example = "2")
    @ExcelProperty(value = "合作状态" ,converter = DictConvert.class)
    @DictFormat("cooperation_status")
    private Integer useStatus;

    @Schema(description = "合作开始时间")
    @ExcelProperty("合作开始时间")
    private LocalDateTime cooperateStartTime;

    @Schema(description = "合作结束时间")
    @ExcelProperty("合作结束时间")
    private LocalDateTime cooperateEndTime;

    @Schema(description = "联系人")
    @ExcelProperty("联系人")
    private String contactMan;

    @Schema(description = "联系电话")
    @ExcelProperty("联系电话")
    private String contactPhone;

    @Schema(description = "联系地址")
    @ExcelProperty("联系地址")
    private String contactAddress;

    @Schema(description = "业务区域")
    @ExcelProperty("业务区域")
    private String businessArea;

    @Schema(description = "合同")
    @ExcelProperty("合同")
    private String contract;

    @Schema(description = "是否系统直连（0：否，1-是）")
    @ExcelProperty(value = "是否系统直连", converter = DictConvert.class)
    @DictFormat("yes_no")
    private Integer isSystemDirect;

    @Schema(description = "系统直连参数")
    @ExcelProperty("系统直连参数")
    private String directParam;

    @Schema(description = "系统直连账号", example = "4537")
    @ExcelProperty("系统直连账号")
    private String directAccount;

    @Schema(description = "系统直连下单地址", example = "https://www.iocoder.cn")
    @ExcelProperty("系统直连下单地址")
    private String directOrderUrl;

    @Schema(description = "系统直连核销地址", example = "https://www.iocoder.cn")
    @ExcelProperty("系统直连核销地址")
    private String directCheckUrl;

    @Schema(description = "系统直连退票地址", example = "https://www.iocoder.cn")
    @ExcelProperty("系统直连退票地址")
    private String directRefundUrl;

    @Schema(description = "直连供应商系统", example = "OtaService")
    private String directServer;

    @Schema(description = "提供资源类型", example = "2")
    @ExcelProperty("提供资源类型")
    private String resourceCategory;

    @Schema(description = "单位名称（同供应商名称）", example = "王五")
    @ExcelProperty("单位名称（同供应商名称）")
    private String unitName;

    @Schema(description = "单位地址")
    @ExcelProperty("单位地址")
    private String unitAddress;

    @Schema(description = "开户行", example = "赵六")
    @ExcelProperty("开户行")
    private String bankName;

    @Schema(description = "银行账户", example = "14227")
    @ExcelProperty("银行账户")
    private String bankAccount;

    @Schema(description = "税号", example = "6791")
    @ExcelProperty("税号")
    private String taxId;

    @Schema(description = "电话")
    @ExcelProperty("电话")
    private String telephone;

    @Schema(description = "联行号")
    @ExcelProperty("联行号")
    private String interbankNumber;

    @Schema(description = "创建时间")
    @ExcelProperty("创建时间")
    private LocalDateTime createTime;

    @Schema(description = "提供资源类型", example = "2")
    private List<Long> resourceType;

}