package com.yc.ship.module.resource.service.project;


import com.yc.ship.framework.common.pojo.PageResult;
import com.yc.ship.module.resource.controller.admin.project.vo.ProjectPageReqVO;
import com.yc.ship.module.resource.controller.admin.project.vo.ProjectSaveReqVO;
import com.yc.ship.module.resource.controller.admin.vo.SimpleListReqVO;
import com.yc.ship.module.resource.dal.dataobject.project.ProjectDO;

import javax.validation.Valid;
import java.util.List;

/**
 * 产品项目 Service 接口
 *
 * @author 管理员
 */
public interface ProjectService {

    /**
     * 创建产品项目
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createProject(@Valid ProjectSaveReqVO createReqVO);

    /**
     * 更新产品项目
     *
     * @param updateReqVO 更新信息
     */
    void updateProject(@Valid ProjectSaveReqVO updateReqVO);

    /**
     * 删除产品项目
     *
     * @param id 编号
     */
    void deleteProject(Long id);

    /**
     * 获得产品项目
     *
     * @param id 编号
     * @return 产品项目
     */
    ProjectDO getProject(Long id);

    /**
     * 获得产品项目分页
     *
     * @param pageReqVO 分页查询
     * @return 产品项目分页
     */
    PageResult<ProjectDO> getProjectPage(ProjectPageReqVO pageReqVO);

    List<ProjectDO> getAllProject();

    List<ProjectDO> getProjectList(ProjectPageReqVO pageReqVO);

    List<ProjectDO> getProjectListByTenant(SimpleListReqVO reqVO);

    List<ProjectDO> getProjectList();
}