package com.yc.ship.module.resource.service.supplier;

import cn.hutool.core.collection.CollUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.yc.ship.framework.common.pojo.PageResult;
import com.yc.ship.framework.common.util.object.BeanUtils;
import com.yc.ship.framework.mybatis.core.util.MyBatisUtils;
import com.yc.ship.module.resource.controller.admin.supplier.vo.*;
import com.yc.ship.module.resource.dal.dataobject.supplier.SupplierDO;
import com.yc.ship.module.resource.dal.mysql.supplier.SupplierMapper;
import com.yc.ship.module.resource.enums.ErrorCodeConstants;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;

import static com.yc.ship.framework.common.exception.util.ServiceExceptionUtil.exception;
import static com.yc.ship.module.system.enums.ErrorCodeConstants.USER_IMPORT_LIST_IS_EMPTY;


/**
 * 资源供应商 Service 实现类
 *
 * @author 管理员
 */
@Service
@Validated
public class SupplierServiceImpl implements SupplierService {

    @Resource
    private SupplierMapper supplierMapper;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Long createSupplier(SupplierSaveReqVO createReqVO) {
        // 插入
        SupplierDO supplier = BeanUtils.toBean(createReqVO, SupplierDO.class);
        Long id = IdWorker.getId(supplier);
        supplier.setId(id);
        supplier.setDeleted(false);
        supplierMapper.insert(supplier);
        // 返回
        return supplier.getId();
    }

    @Override
    @Transactional
    public void updateSupplier(SupplierSaveReqVO updateReqVO) {
        // 校验存在
        validateSupplierExists(updateReqVO.getId());
        // 更新
        SupplierDO updateObj = BeanUtils.toBean(updateReqVO, SupplierDO.class);
        supplierMapper.updateById(updateObj);
    }

    @Override
    @Transactional
    public void deleteSupplier(Long id) {
        // 校验存在
        validateSupplierExists(id);
        // 删除
        supplierMapper.deleteById(id);
    }

    private void validateSupplierExists(Long id) {
        if (supplierMapper.selectById(id) == null) {
            throw exception(ErrorCodeConstants.SUPPLIER_NOT_EXISTS);
        }
    }

    @Override
    public SupplierDO getSupplier(Long id) {
        return  supplierMapper.selectById(id);
    }

    @Override
    public SupplierRespVO getSupplierById(Long id) {
        SupplierDO supplierDO = supplierMapper.selectById(id);
        SupplierRespVO respVO = BeanUtils.toBean(supplierDO, SupplierRespVO.class);
        return respVO;
    }

    @Override
    public PageResult<SupplierRespVO> getSupplierPage(SupplierPageReqVO pageReqVO) {
        IPage<SupplierRespVO> iPage = MyBatisUtils.buildPage(pageReqVO);
        IPage<SupplierRespVO> page = supplierMapper.queryPage(iPage,pageReqVO);
        return new PageResult<>(page.getRecords(),page.getTotal());
    }

    @Override
    public void updateUserStatus(Long id, Integer status) {
        // 校验用户存在
        validateSupplierExists(id);
        // 更新状态
        SupplierDO supplier = new SupplierDO();
        supplier.setId(id);
        supplier.setUseStatus(status);
        supplierMapper.updateById(supplier);
    }

    @Override
    public SupplierImportRespVO importSupplierList(List<SupplierImportExcelVO> list, Boolean updateSupport) {
        if (CollUtil.isEmpty(list)) {
            throw exception(USER_IMPORT_LIST_IS_EMPTY);
        }
        SupplierImportRespVO respVO = SupplierImportRespVO.builder().createSuppliers(new ArrayList<>())
                .updateSuppliers(new ArrayList<>()).failureSuppliers(new LinkedHashMap<>()).build();
        list.forEach(importUser -> {
            // 校验，判断是否有不符合的原因

        });
        return respVO;

    }

    @Override
    public List<SupplierDO> getSimpleListByCategory(SupplierListReqVO reqVO) {

        return supplierMapper.getSimpleListByCategory(reqVO);
    }

    @Override
    public SupplierRespVO getSupplierByDirectAccount(String directAccount) {
        List<SupplierDO> lidst = supplierMapper.selectList(SupplierDO::getDirectAccount, directAccount);
        if(lidst!=null && lidst.size()>0){
            SupplierDO supplierDO = lidst.get(0);
            SupplierRespVO respVO = BeanUtils.toBean(supplierDO, SupplierRespVO.class);
            return respVO;
        }
        return null;
    }
}